class: Workflow
cwlVersion: v1.2.0-dev2
doc: 'Abstract CWL Automatically generated from the Galaxy workflow file: VGP hybrid
  scaffolding with HiC data'
inputs:
  Estimated genome size - Parameter File:
    doc: Parameter file generated in the VGP Hifiasm workflow. Estimated reference
      genome size (in bp) for computing NGx statistics
    format: data
    type: File
  HiC Forward reads:
    doc: HiC forward reads in Fastq Format. The reads must be in the same order as
      reverse reads.
    format: data
    type: File
  HiC reverse reads:
    doc: HiC reverse reads in Fastq Format. The reads must be in the same order as
      forward reads.
    format: data
    type: File
  'Restriction enzyme sequences ':
    doc: File containing the list of restriction enzymes used by Arima technology,
      the sequences are separated by a comma. In the VGP project AWS, the restriction
      enzyme sequences can be found in the repository containing HiC data.
    format: data
    type: File
  Scaffolded Assembly:
    doc: Scaffold generated by "VGP Bionano" workflows or contigs Generated by the
      "VGP Hifiasm" workflow.
    format: data
    type: File
  Sequence graph - Optional:
    doc: Sequence graphs encoded in GFA format. (-g)
    format: data
    type: File
outputs: {}
steps:
  10_Parse parameter value:
    in:
      input1: 'Restriction enzyme sequences '
    out:
    - text_param
    run:
      class: Operation
      id: param_value_from_file
      inputs:
        input1:
          format: Any
          type: File
      outputs:
        text_param:
          doc: expression.json
          type: File
  11_Parse parameter value:
    in:
      input1: Estimated genome size - Parameter File
    out:
    - integer_param
    run:
      class: Operation
      id: param_value_from_file
      inputs:
        input1:
          format: Any
          type: File
      outputs:
        integer_param:
          doc: expression.json
          type: File
  12_Filter and merge:
    in:
      forward: 8_BWA-MEM2/bam_output
      reverse: 9_BWA-MEM2/bam_output
    out:
    - outfile
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_bellerophon_bellerophon_1_0+galaxy0
      inputs:
        forward:
          format: Any
          type: File
        reverse:
          format: Any
          type: File
      outputs:
        outfile:
          doc: bam
          type: File
  13_bedtools BAM to BED:
    in:
      input: 12_Filter and merge/outfile
    out:
    - output
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_bedtools_bedtools_bamtobed_2_30_0+galaxy2
      inputs:
        input:
          format: Any
          type: File
      outputs:
        output:
          doc: bed
          type: File
  14_PretextMap:
    in:
      input: 12_Filter and merge/outfile
    out:
    - pretext_map_out
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_pretext_map_pretext_map_0_1_8+galaxy2
      inputs:
        input:
          format: Any
          type: File
      outputs:
        pretext_map_out:
          doc: pretext
          type: File
  15_Sort:
    in:
      input: 13_bedtools BAM to BED/output
    out:
    - out_file1
    run:
      class: Operation
      id: sort1
      inputs:
        input:
          format: Any
          type: File
      outputs:
        out_file1:
          doc: input
          type: File
  16_Pretext Snapshot:
    in:
      input: 14_PretextMap/pretext_map_out
    out:
    - pretext_snap_out
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_pretext_snapshot_pretext_snapshot_0_0_3+galaxy1
      inputs:
        input:
          format: Any
          type: File
      outputs:
        pretext_snap_out:
          doc: input
          type: File
  17_SALSA:
    in:
      bed_file: 15_Sort/out_file1
      enzyme_conditional|manual_enzyme: 10_Parse parameter value/text_param
      fasta_in: 7_Replace/outfile
      gfa_file: Sequence graph - Optional
    out:
    - scaffolds_fasta
    - scaffolds_agp
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_salsa_salsa_2_3+galaxy2
      inputs:
        bed_file:
          format: Any
          type: File
        enzyme_conditional|manual_enzyme:
          format: Any
          type: File
        fasta_in:
          format: Any
          type: File
        gfa_file:
          format: Any
          type: File
      outputs:
        scaffolds_agp:
          doc: tabular
          type: File
        scaffolds_fasta:
          doc: fasta
          type: File
  18_Busco:
    in:
      input: 17_SALSA/scaffolds_fasta
    out:
    - busco_sum
    - busco_table
    - busco_missing
    - summary_image
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_busco_busco_5_2_2+galaxy2
      inputs:
        input:
          format: Any
          type: File
      outputs:
        busco_missing:
          doc: tabular
          type: File
        busco_sum:
          doc: txt
          type: File
        busco_table:
          doc: tabular
          type: File
        summary_image:
          doc: png
          type: File
  19_BWA-MEM2:
    in:
      fastq_input|fastq_input1: HiC Forward reads
      reference_source|ref_file: 17_SALSA/scaffolds_fasta
    out:
    - bam_output
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_bwa_mem2_bwa_mem2_2_2_1+galaxy0
      inputs:
        fastq_input|fastq_input1:
          format: Any
          type: File
        reference_source|ref_file:
          format: Any
          type: File
      outputs:
        bam_output:
          doc: bam
          type: File
  20_BWA-MEM2:
    in:
      fastq_input|fastq_input1: HiC reverse reads
      reference_source|ref_file: 17_SALSA/scaffolds_fasta
    out:
    - bam_output
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_bwa_mem2_bwa_mem2_2_2_1+galaxy0
      inputs:
        fastq_input|fastq_input1:
          format: Any
          type: File
        reference_source|ref_file:
          format: Any
          type: File
      outputs:
        bam_output:
          doc: bam
          type: File
  21_Quast:
    in:
      assembly|ref|est_ref_size: 11_Parse parameter value/integer_param
      in|inputs: 17_SALSA/scaffolds_fasta
      large: 6_Input parameter/output
    out:
    - quast_tabular
    - report_html
    - report_pdf
    - log
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_quast_quast_5_0_2+galaxy3
      inputs:
        assembly|ref|est_ref_size:
          format: Any
          type: File
        in|inputs:
          format: Any
          type: File
        large:
          format: Any
          type: File
      outputs:
        log:
          doc: txt
          type: File
        quast_tabular:
          doc: tabular
          type: File
        report_html:
          doc: html
          type: File
        report_pdf:
          doc: pdf
          type: File
  22_Filter and merge:
    in:
      forward: 19_BWA-MEM2/bam_output
      reverse: 20_BWA-MEM2/bam_output
    out:
    - outfile
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_bellerophon_bellerophon_1_0+galaxy0
      inputs:
        forward:
          format: Any
          type: File
        reverse:
          format: Any
          type: File
      outputs:
        outfile:
          doc: bam
          type: File
  23_PretextMap:
    in:
      input: 22_Filter and merge/outfile
    out:
    - pretext_map_out
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_pretext_map_pretext_map_0_1_8+galaxy2
      inputs:
        input:
          format: Any
          type: File
      outputs:
        pretext_map_out:
          doc: pretext
          type: File
  24_Pretext Snapshot:
    in:
      input: 23_PretextMap/pretext_map_out
    out:
    - pretext_snap_out
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_pretext_snapshot_pretext_snapshot_0_0_3+galaxy1
      inputs:
        input:
          format: Any
          type: File
      outputs:
        pretext_snap_out:
          doc: input
          type: File
  6_Input parameter:
    in: {}
    out: []
    run:
      class: Operation
      id: null
      inputs: {}
      outputs: {}
  7_Replace:
    in:
      infile: Scaffolded Assembly
    out:
    - outfile
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_bgruening_text_processing_tp_find_and_replace_1_1_3
      inputs:
        infile:
          format: Any
          type: File
      outputs:
        outfile:
          doc: input
          type: File
  8_BWA-MEM2:
    in:
      fastq_input|fastq_input1: HiC Forward reads
      reference_source|ref_file: Scaffolded Assembly
    out:
    - bam_output
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_bwa_mem2_bwa_mem2_2_2_1+galaxy0
      inputs:
        fastq_input|fastq_input1:
          format: Any
          type: File
        reference_source|ref_file:
          format: Any
          type: File
      outputs:
        bam_output:
          doc: bam
          type: File
  9_BWA-MEM2:
    in:
      fastq_input|fastq_input1: HiC reverse reads
      reference_source|ref_file: Scaffolded Assembly
    out:
    - bam_output
    run:
      class: Operation
      id: toolshed_g2_bx_psu_edu_repos_iuc_bwa_mem2_bwa_mem2_2_2_1+galaxy0
      inputs:
        fastq_input|fastq_input1:
          format: Any
          type: File
        reference_source|ref_file:
          format: Any
          type: File
      outputs:
        bam_output:
          doc: bam
          type: File

